@@ -256,13 +256,18 @@ class LabeledView(LabelingMixin, View):
     def __neg__(self):
         return self.layer_on(-self.tensor)
 
+    def to_dense(self):
+        return self.layer_on(self.tensor.to_dense())
+
+    def to_sparse(self):
+        return self.layer_on(self.tensor.to_sparse())
+
     def dot(self, other):
         """
         For first-order tensors, this is a dot product. For second-order,
         it performs matrix multiplication. Like Numpy matrices (not arrays),
         this is the operation performed by the * operator.
         """
-        assert self.shape[-1] == other.shape[0]
         label_lists = [self.label_list(i) for i in xrange(self.ndim-1)]
         if hasattr(other, 'label_list'):
             data = self.tensor.dot(other.tensor)
@@ -301,6 +306,8 @@ class LabeledView(LabelingMixin, View):
     def cmul(self, other):
         return self.layer_on(self.tensor.cmul(other))
 
+    def hat(self):
+        return self.layer_on(self.tensor.hat())
 
     def svd(self, *a, **kw):
         if self.ndim == 2:
