@@ -134,7 +134,7 @@ class SVD2DResults(object):
         matrix from an SVD.
         '''
         if self._core is None:
-            self._core = DenseTensor(numpy.diag(self.svals))
+            self._core = DenseTensor(numpy.diag(self.svals.to_dense()._data))
         return self._core
     
     @property
@@ -588,6 +588,9 @@ def incremental_svd(tensor, k=50, niter=100, lrate=.1, logging_interval=None):
     gradient descent process (default 100).
     '''
     assert(tensor.ndim == 2)
+    if not isinstance(tensor, Tensor):
+        raise TypeError("This function can only be run on a Tensor. Use the "
+                        ".incremental_svd() method for other objects.")
         
     u, v, sigma = tensor._isvd(k=k, niter=niter, lrate=lrate)
     return SVD2DResults(u, v, sigma)
