@@ -31,6 +31,7 @@ def isscalar(obj):
     return len(getattr(obj, 'shape', ())) == 0
 
 TheEmptySlice = slice(None)
+EPSILON = 1e-12
 
 # Subclasses of Tensor need at a bare minimum:
 #  - ndim
@@ -323,7 +324,17 @@ class Tensor(MyDictMixin):
         return math.sqrt(mag)
 
     magnitude = norm
+    
+    def hat(self):
+        '''
+        Return a normalized version of this tensor (generally a vector), by
+        dividing by its norm.
 
+        This is not the same as .normalized(), which normalizes all the things
+        (generally vectors) that make up a tensor (generally a matrix), using a
+        NormalizedView.
+        '''
+        return self / max(self.norm(), EPSILON)
 
     ## Vector operations
     # Most of the operations below only make sense on vectors.
@@ -649,7 +660,7 @@ class DictTensor(Tensor):
                     for x in iter_helper(child_dict, num_nested - 1, key_base + (key,)):
                         yield x
         return iter_helper(self._data, self.ndim, ())
-    
+
     @property
     def shape(self):
         """
@@ -821,8 +832,12 @@ class DictTensor(Tensor):
     # * tensor products:
     #   - tensordot: tensor by vector (param: mode)
     #   - tensor by matrix: also takes mode param
-    
-    def dot(self, other, mode=0, into=None):
+
+    def dot(self, other, mode=0, into=None, reverse=False):
+        if max(self.ndim, other.ndim) == 1:
+            return self._vectordot(other, reverse=reverse)
+        if max(self.ndim, other.ndim) == 2:
+            return self._2ddot(other, reverse=reverse)
         raise NotImplementedError
 #         if into is None:
 #             into = DictTensor(2) # FIXME
@@ -842,6 +857,38 @@ class DictTensor(Tensor):
             return result[()]
         return DenseTensor(result)
 
+    def _vectordot(self, other, reverse=False):
+        if other.ndim != 1:
+            raise IndexError("Incompatible dimensions for sparse vectordot (%r._vectordot(%r)" % (self, other))
+        if not isinstance(other, DictTensor):
+            other = other.to_sparse()
+        if len(other) < len(self):
+            other, self = self, other
+        return sum(value * other.get(key, 0) for key, value in self.iteritems())
+
+    def _2ddot(self, other, reverse=False):
+        if reverse:
+            other, self = self, other
+        if self.ndim < other.ndim:
+            raise IndexError("Incompatible order in sparse 2ddot: (%r._2ddot(%r))" % (self, other))
+        if self.shape[1] != other.shape[0]:
+            raise IndexError("Dimension Mismatch in sparse 2ddot: (%r._2ddot(%r))" % (self, other))
+
+        result = DictTensor(other.ndim)
+
+        if other.ndim == 1:
+            # Simple case:
+            for key, value in self.iteritems():
+                i, j = key
+                result._data[i] = result._data.get(i, 0) + value * other._data.get(j, 0)
+        else:
+            for key, value in self.iteritems():
+                i, j = key
+                for k, v2 in other._data.get(j, {}).iteritems():
+                    result[(i, k)] = result.get((i, k)) + value * v2
+
+        return result
+
     def tensor_by_matrix(self, other, mode):
         pass
 
@@ -1045,6 +1092,8 @@ class DenseTensor(Tensor):
 
     # Math operations
     def dot(self, other):
+        if isinstance(other, DictTensor):
+            return other.dot(self, reverse=True)
         # FIXME: this will need additional cases for other types of tensors.
         return wrap_unless_scalar(numpy.dot(self._data, data(other)))
 
@@ -1087,13 +1136,14 @@ class DenseTensor(Tensor):
     def to_dense(self):
         return self
 
-    def to_sparse(self):
+    def to_sparse(self, default_value=0.0):
         """
         Convert this to a :class:`DictTensor`.
         """
         result = DictTensor(self.ndim)
         for key, val in self.iteritems():
-            if val == 0: continue
+            if val == default_value:
+                continue
             result[key] = val
         return result
 
