@@ -29,16 +29,33 @@ def test_manual_weights():
     Specifying weights manually causes the result to be the weighted sum.
     '''
     b = Blend([t1, t2], weights=[.75,.25])
-
+    b.build_tensor()
     expected = dict(zip(zip('aabc', '1211'), (.75, 1.0, .75, .25)))
     assertTensorEqualCompleteDict(b, expected)
 
+def test_fake_tensor():
+    '''
+    Blends have a fake tensor that does iteritems really fast.
+    '''
+    # labels will be abc, 12
+    t3 = ez_matrix('c', '1', [1])
+    b = Blend([t1, t3], weights=[.75,.25])
+    fake_tensor = b.fake_tensor()
+    items = set(fake_tensor.iteritems())
+    expected_items = set((
+            ((0,0), .75),
+            ((0,1), .75),
+            ((1,0), .75),
+            ((2,0), .25)))
+    assertSetEquals(items, expected_items)
+
 def test_no_overlap():
     '''
     Certain optimizations are possible if there is no overlap.
     '''
     t2 = ez_matrix('dc', '21', [1]*2)
     b = Blend([t1, t2], weights=[.75,.25])
+    b.build_tensor()
     expected = dict(zip(zip('aabdc', '12121'), (.75, .75, .75, .25, .25)))
     assertTensorEqualCompleteDict(b, expected)
     
@@ -80,6 +97,7 @@ def test_autoblend():
     assert allclose(b.weights, [.75, .25])
 
     # Test the resulting tensor
+    b.build_tensor()
     # -non-overlapping elements
     assert t1['0', '0'] == 1
     assert_almost_equal(b['0', '0'], .75*1) # remember that the original tensors had non-unity values.
@@ -113,7 +131,16 @@ def test_rough_blend():
     t2 = MockTensor()
     t2.svals = range(15, 0, -3)
 
-    b = Blend([t1, t2])
+    b = Blend([t1, t2], k_values=1)
+    eq_(b.weights, (.75, .25))
+
+def test_rough_blend2():
+    '''
+    You can pass in the svals and it doesn't try to compute them.
+    '''
+    t1 = MockTensor()
+    t2 = MockTensor()
+    b = Blend([t1, t2], k_values=1, svals=[range(5,0,-1), range(15,0,-3)])
     eq_(b.weights, (.75, .25))
     
 def test_predicted_svals():
@@ -127,7 +154,7 @@ def test_predicted_svals():
 
     # Weighting one side heavily should make its svals uniquely show up.
     weight = 0.999999
-    b = Blend([t1, t2], weights=[weight, 1-weight])
+    b = Blend([t1, t2], weights=[weight, 1-weight], k_values=1)
 
     # with origin tracking:
     svals = b.predicted_svals(num=5, for_each_tensor=5, track_origin=True)
