@@ -1,6 +1,7 @@
 from nose.tools import *
 from csc.divisi.ordered_set import OrderedSet, IdentitySet
 
+import cPickle as pickle
 
 def test_reprOfEmpty():
     '''
@@ -19,6 +20,12 @@ def test_identity():
     eq_(len(iset), 10)
     assert iset == OrderedSet(range(10))
 
+    iset = pickle.loads(pickle.dumps(iset))
+    eq_(iset[5], 5)
+    eq_(iset.index(2), 2)
+    eq_(len(iset), 10)
+    assert iset == OrderedSet(range(10))
+    
 def test_pickle():
     '''
     Test that OrderedSets can be pickled.
@@ -43,7 +50,6 @@ def test_delete_and_pickle():
     eq_(s.index('banana'), 2)
 
     # Pickling doesn't change things.
-    import cPickle as pickle
     s2 = pickle.loads(pickle.dumps(s))
 
     eq_(s, s2)
