@@ -1,9 +1,9 @@
-from csc.divisi.tensor import DenseTensor
+from csc.divisi.tensor import DenseTensor, DictTensor
 from csc.divisi.labeled_view import LabeledView
 from nose.tools import eq_, assert_almost_equal, raises
-from numpy import zeros, sqrt
+from numpy import zeros, sqrt, array
 
-def testDotProduct():
+def testDotProductZeros():
     # Set up two tensors
     tensor = DenseTensor(zeros((5,)))
     tensor2 = DenseTensor(zeros(5,))
@@ -11,6 +11,41 @@ def testDotProduct():
     result = tensor * tensor2
     eq_(result, 0)
 
+def testDotProduct():
+    tensor = DenseTensor(array([0.14687186,
+                                0.36171911,
+                                0.21347318,
+                                0.46414277,
+                                0.04449569]))
+    tensor2 = DenseTensor(array([0.70729209,
+                                 0.31895484,
+                                 0.78696611,
+                                 0.71827665,
+                                 0.87118245]))
+    result = tensor * tensor2
+    assert_almost_equal(result, 0.75939630191647056)
+
+def testDictDotProduct():
+    tensor = DictTensor(1)
+    tensor.update({
+            1: 0.06198828,
+            3: 0.24177249,
+            6: 0.5256805,
+            7: 0.46505895,
+            8: 0.27791615,
+            9: 0.02906779})
+    tensor2 = DictTensor(1)
+    tensor2.update({
+            0: 0.2502674,
+            2: 0.34907184,
+            3: 0.2209139,
+            5: 0.45788618,
+            6: 0.37133328,
+            7: 0.48278861})
+
+    result = tensor * tensor2
+    assert_almost_equal(result, 0.473138731464)
+
 def testAdding():
     # Set up two tensors.
     tensor = DenseTensor(zeros((5,)))
