@@ -586,14 +586,14 @@ class SVD2DTest(unittest.TestCase):
                                [[0, 0, 1],
                                 [0, -1, 0],
                                 [0, 0, 0],
-                                [-1, 0, 0]])
+                                [-1, 0, 0]], abs=True)
 
         assertTensorEqual(self.v, 
                                [[0, 0, sqrt(.2)],
                                 [-1, 0, 0],
                                 [0, -1, 0],
                                 [0, 0, 0],
-                                [0, 0, sqrt(.8)]])
+                                [0, 0, sqrt(.8)]], abs=True)
 
         assertTensorEqual(self.svals,
                                [4, 3, sqrt(5)])
